diff flvenc.c @ 3250:9c5e50e5eac0 libavformat

set wrap bits to 32bit to actually use it
author bcoudurier
date Fri, 25 Apr 2008 09:04:38 +0000
parents 8ae0431d7f43
children 83a8b43761bc
line wrap: on
line diff
--- a/flvenc.c	Thu Apr 24 23:21:58 2008 +0000
+++ b/flvenc.c	Fri Apr 25 09:04:38 2008 +0000
@@ -163,7 +163,7 @@
             if(get_audio_flags(enc)<0)
                 return -1;
         }
-        av_set_pts_info(s->streams[i], 24, 1, 1000); /* 24 bit pts in ms */
+        av_set_pts_info(s->streams[i], 32, 1, 1000); /* 32 bit pts in ms */
     }
     put_tag(pb,"FLV");
     put_byte(pb,1);